<?php

namespace App\Http\Controllers\Admin;

use Illuminate\Http\Request;
use App\Http\Requests\GroupRequest;
use App\Http\Requests\RevisorGroupAddedRequest;
use App\Http\Requests\ProjectAssignedGroupRequest;

use App\Http\Controllers\Controller;

use Spatie\Permission\Models\Role;

use App\Group;
use App\User;
use App\Stage;

use Session;
use DB;

class GroupController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $args = [

            'groups' => Group::select('groups.id', 'groups.name')->get(),

        ];

        return view('admin.models.group.collection', $args);
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        return view('admin.models.group.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(GroupRequest $request)
    {
        $grupo = new Group();
        $grupo->name = $request->name;
        $grupo->slug = $request->slug;

        $grupo->save();

        $request->session()->flash('guardado', 'Grupo creado correctamente');

        return back();
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $group= Group::find($id);

        $revisoresDelGrupo = DB::table('group_revisor')
                                    ->join('users', 'users.id', '=', 'group_revisor.revisor_id')
                                    ->where('group_revisor.group_id', '=', $id)
                                    ->select('group_revisor.*', 'users.name as nombreRevisor')
                                    ->get();

        if (is_null($group)) {
            abort('404');
        }

        //Proyectos asignados al grupo
        $proyectosAsignados = DB::table('project_revisor')
                                    ->join('projects', 'projects.id', '=', 'project_revisor.project_id')
                                    ->join('stages', 'stages.id', '=', 'project_revisor.stage_id')
                                    ->where('project_revisor.group_id', '=', $id)
            
                                    ->select('project_revisor.*', 'stages.name as nombreEtapa', 'projects.title as tituloProyecto')
                                        ->groupBy('project_revisor.project_id')

                                        ->orderBy('project_revisor.stage_id', 'asc')
                                        ->get();

        // dd($proyectosAsignados);


        $args = [
            'group' => $group,
            'revisoresDelGrupo' => $revisoresDelGrupo,
            'proyectosAsignados' => $proyectosAsignados,
        ];

        return view('admin.models.group.edit', $args);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(GroupRequest $request, $id)
    {
        $group = Group::find($id);
        $group->name = $request->name;
        $group->slug = $request->slug;
        $group->save();

        Session::flash('guardado', 'Editado correctamente');

        return back();
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        // DB::table('groups')->where('id', $id)->delete();

        // Session::flash('grupoEliminado', 'Grupo eliminado');

        // return back();
    }

    //Listar integrantes de un grupo
    public function getRevisorGroup(){
        $usuarios = User::role('revisor')->get();


        foreach ($usuarios as $key => $value) {
            $tieneGrupo= DB::table('group_revisor')
                    ->where('revisor_id', '=', $value->id)
                    ->get();

            if ($tieneGrupo->isNotEmpty()) {
                $usuarios->pull($key);
            }    
        }
        

        $resultado = \Response::json($usuarios);
        // dd($resultado);

        return $resultado; 
    }

    //Agregar integrantes a un grupo
    public function addRevisorGroup(RevisorGroupAddedRequest $request){
        foreach ($request->revisores as $key => $value) {
            // dd($request);
            DB::table('group_revisor')->insert(
                    [
                        'revisor_id' => $value,
                        'group_id' => $request->idGroup, 
                    ]
            );
        }

        return redirect()->action('Admin\GroupController@edit', ['id' => $request->idGroup])
                                ->with('revisorAgregado', 'Revisor agregado al grupo');
    }

    //Quitar un revisor del grupo
    public function removeRevisorGroup($id){
        DB::table('group_revisor')->where('id', $id)->delete();

        // para mostrar msj de exito
        Session::flash('revisorQuitado', 'quitado correctamente');

        return back();
    }

    // ************************************************************************
    // asignacion de proyectos al grupo
    // Selects de etapas
    public function getStagesGroup(Request $request){
        $etapas = Stage::get();

        $nuevo = array();

        foreach ($etapas as $key => $value) {

            if(empty($nuevo[$value['id']])){
                $nuevo[$value['id']] = $value;
            }

        }

        $resultado = \Response::json(array_values($nuevo));
        // dd($resultado);

        return $resultado;
    }

    // Selects de proyectos
    public function getProjectsGroup(Request $request){
        $proyectoYaAsignado = DB::table('project_revisor')
                        ->get();

        $coleccion = collect();

        foreach ($proyectoYaAsignado as $key => $value) {
            
            if ($value->group_id == $request->idGroup) {
                $coleccion->push($value);
            }elseif ($value->stage_id == $request->idStage && !is_null($value->group_id)) {
                    $coleccion->push($value);
            }

        }
        // dd($coleccion);
        // dd($proyectoYaAsignado);


        $proyectos = \DB::table('projects')
                        ->where('projects.title', '<>', NULL)
                        ->where('projects.active', '=', 1)
                        ->get();

        $proyectosDisponibles = $proyectos->whereNotIn('id', $coleccion->pluck('project_id')->toArray());

        // dd($proyectosDisponibles);

        $nuevo = array();

        foreach ($proyectosDisponibles as $key => $value) {

            if(empty($nuevo[$value->id])){
                $nuevo[$value->id] = $value;
            }

        }

        $resultado = \Response::json(array_values($nuevo));
        // dd($resultado);

        return $resultado;
    }

    // Guardar proyectos asigandos al grupo
    public function saveProjectsGroup(ProjectAssignedGroupRequest $request){
        $revisoresDelGrupo = DB::table('group_revisor')
                                    ->join('users', 'users.id', '=', 'group_revisor.revisor_id')
                                    ->where('group_revisor.group_id', '=', $request->idGroup)
                                    ->select('users.*')
                                    ->get();
        // dd($revisoresDelGrupo);

        foreach ($request->projects as $keyProyecto => $valueProyecto) {
            foreach ($revisoresDelGrupo as $keyRevisor => $valueRevisor) {
                // $existeAsignacion = DB::table('project_revisor')
                //                             ->where('project_id', $valueProyecto)
                //                             ->where('revisor_id', $valueRevisor->id)
                //                             ->where('stage_id', $request->stages)
                //                             ->get();

                // if ($existeAsignacion->isEmpty()) {
                    DB::table('project_revisor')->insert(
                            [
                                'project_id' => $valueProyecto, 
                                'revisor_id' => $valueRevisor->id,
                                'group_id' => $request->idGroup,
                                'stage_id' => $request->stages
                            ]
                    );
                // }
            }
        }

        return redirect()->action('Admin\GroupController@edit', ['id' => $request->idGroup])
                                ->with('asignado', 'Proyecto asignado');
    }


    //Eliminar una asignacion de proyecto
    public function removeProjectGroup(Request $request){
        // dd($request);
        DB::table('project_revisor')
                    ->where('group_id', $request->idGroup)
                    ->where('project_id', $request->idProject)
                    ->where('stage_id', $request->idStage)
                    ->delete();

        // para mostrar msj de exito
        Session::flash('asignacionBorrada', 'quitado correctamente');

        return back();
    }
}
