<?php

namespace App\Http\Controllers\Admin;

use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use App\Http\Controllers\Admin\InscriptionController;
use Illuminate\Support\Collection;

use App\Http\Requests\UserRequest;
use App\Http\Requests\ProjectAssignedRequest;

use Spatie\Permission\Models\Role;

use App\User;
use App\Userdata;
use App\Stage;

use DB;
use Session;
use Hash;
use Auth;

class UserController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $noEsSuperAdmin = false;
        $usuariosSuperAdmin = User::role('superadmin')->select('id')->get()->pluck('id')->toArray();
        // dd($usuariosSuperAdmin);

        // usuario logueado
        $user = Auth::user();        
        if (! $user->hasRole('superadmin')) {
            $noEsSuperAdmin = true;
        }
        
        $usuarios = User::join('model_has_roles', 'model_has_roles.model_id', '=', 'users.id')

                        ->when($noEsSuperAdmin, function ($query) use ($usuariosSuperAdmin) {
                            return $query->whereNotIn('id', $usuariosSuperAdmin);
                        })

                        ->select('users.id', 'users.name')

                        ->groupBy('users.id')
                        ->orderBy('model_has_roles.role_id', 'asc')
                        ->orderby('users.id', 'asc')
                        ->get();
        $args = [

            'users' => $usuarios,

        ];

        return view('admin.models.user.collection', $args);
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $listaDeRoles = array();

        $data = DB::table('roles')->get();
        $roles = $data->filter(function ($value, $key){
            return $value->name != 'superadmin';
        })->toArray();

        foreach ($roles as $key => $value) {
            $listaDeRoles[$value->name] = $value->name;
        }
        

        $args = [
            'roles' => $listaDeRoles,
        ];

        return view('admin.models.user.create', $args);
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(UserRequest $request)
    {
        //create user
            $user = User::where('email', $request->email)->first();

            if (!$user) {
                $user = new User();
                $user->name = $request->user;
                $user->password = Hash::make($request->password);
                $user->email = $request->email;
                $user->save();


                // create userdata

                $userdata = new Userdata();
                $userdata->name = $request->name;
                $userdata->surname = $request->surname;
                $userdata->user_id = $user->id;
                $userdata->city = '';


                $userdata->save();

                //asignar rol
                $user->assignRole($request->rol);
            }

            // falta redirect
            Session::flash('guardado', 'creado correctamente');
            return back();
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {

        $listaDeRoles = array();

        $data = DB::table('roles')->get();
        $roles = $data->filter(function ($value, $key){
            return $value->name != 'superadmin';
        })->toArray();

        foreach ($roles as $key => $value) {
            $listaDeRoles[$value->name] = $value->name;
        }

        //usuario con data
        $userConData = User::join('userdata', 'users.id', '=', 'userdata.user_id')
                    ->select('users.id as id', 'users.email', 'userdata.name', 'userdata.surname', 'users.name as user')
                    ->where('users.id', $id)
                    ->get()
                    ->first();

        if (is_null($userConData)) {
            abort('404');
        }

        //rol del usuario
        $user= User::find($id);
        if ($user->hasAnyRole(Role::all())) {
            // $rol = $user->getRoleNames()[0];
            $rol = $user->getRoleNames()->toArray();
        }else{
            $rol = '';
        }


        $userConData->rol = $rol;
        // dd($userConData);

        if (in_array('revisor', $userConData->rol)) {
            //Proyectos asignados si es revisor
            $proyectosAsignados = DB::table('project_revisor')
                                        ->join('projects', 'projects.id', '=', 'project_revisor.project_id')
                                        ->join('stages', 'stages.id', '=', 'project_revisor.stage_id')
                                        
                                        ->where('project_revisor.revisor_id', '=', $id)
                                        ->where('projects.active', '=', 1)

                                        ->select('project_revisor.*', 'stages.name as nombreEtapa', 'projects.title as tituloProyecto', 'projects.origin_id')

                                        ->orderBy('projects.origin_id', 'asc')
                                        ->orderBy('project_revisor.stage_id', 'asc')
                                        ->get();
            
            // dd($proyectosAsignados);

            $total_proyectos = $proyectosAsignados->count();

            // agregar si reseño o no | 1 => Evaluado, 2 = > En Proceso, 3 = > NO Evaluado
            $inscriptionController = new InscriptionController();

            $evaluados = $inscriptionController->filtroResenia(1);
            $enProceso = $inscriptionController->filtroResenia(2);
            $noEvaluadosQuitar = $inscriptionController->filtroResenia(3);
            
            foreach ($proyectosAsignados as $key => $value) {
                if (in_array($value->project_id, $evaluados)) {
                    $value->reseniado = 'EVALUADO';
                } elseif (in_array($value->project_id, $enProceso)) {
                    $value->reseniado = 'EN PROCESO';
                } else {
                    $value->reseniado = 'NO EVALUADO';
                }
            }
            
            // dd($proyectosAsignados->groupBy('reseniado'));

            $coleccion_evaluados = $proyectosAsignados->filter(function ($value, $key) {
                return $value->reseniado == "EVALUADO";
            });

            $cantidad_proyectos_evaluados = $coleccion_evaluados->count();

            $coleccion_NO_evaluados = $proyectosAsignados->filter(function ($value, $key) {
                return $value->reseniado == "NO EVALUADO";
            });

            $cantidad_proyectos_pendientes = $coleccion_NO_evaluados->count();

        }else{
            $proyectosAsignados = null;
            $total_proyectos = null;
            $cantidad_proyectos_evaluados = null;
            $cantidad_proyectos_pendientes = null;
        }

        $args = [
            'roles' => $listaDeRoles,
            'user' => $userConData,
            'proyectosAsignados' => $proyectosAsignados,
            'total_proyectos' => $total_proyectos,
            'cantidad_proyectos_evaluados' => $cantidad_proyectos_evaluados,
            'cantidad_proyectos_pendientes' => $cantidad_proyectos_pendientes,
        ];


        return view('admin.models.user.edit', $args);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(UserRequest $request, $id)
    {
        $user = User::find($id);
        $user->name = $request->user;
        $user->email = $request->email;
        $user->save();

        $userdata = Userdata::where('user_id', $id)->get()->first();
        $userdata->name = $request->name;
        $userdata->surname = $request->surname;
        $userdata->save();

        $user->syncRoles($request->rol);

        Session::flash('guardado', 'Editado correctamente');

        return back();
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        //
    }


    public function slugify($text)
    {
        // replace non letter or digits by -
        $text = preg_replace('~[^\pL\d]+~u', '-', $text);
        // transliterate
        $text = iconv('utf-8', 'us-ascii//TRANSLIT', $text);
        // remove unwanted characters
        $text = preg_replace('~[^-\w]+~', '', $text);
        // trim
        $text = trim($text, '-');
        // remove duplicate -
        $text = preg_replace('~-+~', '-', $text);
        // lowercase
        $text = strtolower($text);
        if (empty($text)) {
            return 'n-a';
        }
        return $text;
    }

    // Selects de etapas
    public function getStages(Request $request){
        $etapas = Stage::get();

        $nuevo = array();

        foreach ($etapas as $key => $value) {

            if(empty($nuevo[$value['id']])){
                $nuevo[$value['id']] = $value;
            }

        }

        $resultado = \Response::json(array_values($nuevo));
        // dd($resultado);

        return $resultado;
    }

    // Selects de proyectos
    public function getProjects(Request $request){
        $proyectoYaAsignado = DB::table('project_revisor')
                        ->get();

        $coleccion = collect();

        foreach ($proyectoYaAsignado as $key => $value) {
            //sin grupos y estricto
            // if ($value->revisor_id == $request->idRevisor) {
            //     $coleccion->push($value);
            // }elseif ($value->stage_id == $request->idStage) {
            //     $coleccion->push($value);
            // }

            //Sin restriccion, no probado
            if ($value->stage_id == $request->idStage) {
                $coleccion->push($value);
            }

        }
        // dd($coleccion);
        // dd($proyectoYaAsignado);


        $proyectos = \DB::table('projects')
                        ->where('projects.title', '<>', NULL)
                        ->where('projects.active', '=', 1)
                        ->get();

        $proyectosDisponibles = $proyectos->whereNotIn('id', $coleccion->pluck('project_id')->toArray());

        // dd($proyectosDisponibles);

        $nuevo = array();

        foreach ($proyectosDisponibles as $key => $value) {

            if(empty($nuevo[$value->id])){
                $nuevo[$value->id] = $value;
            }

        }

        $resultado = \Response::json(array_values($nuevo));
        // dd($resultado);

        return $resultado;
    }

    // Guardar proyectos asigandos a revisores
    public function saveProjects(ProjectAssignedRequest $request){
        foreach ($request->projects as $key => $value) {
            DB::table('project_revisor')->insert(
                    [
                        'project_id' => $value, 
                        'revisor_id' => $request->idRevisor,
                        'stage_id' => $request->stages
                    ]
            );
        }

        return redirect()->action('Admin\UserController@edit', ['id' => $request->idRevisor])
                                ->with('asignado', 'Proyecto asignado');
    }


    //Eliminar una asignacion de proyecto
    public function removeProject($id){
        DB::table('project_revisor')->where('id', $id)->delete();

        // para mostrar msj de exito
        Session::flash('asignacionBorrada', 'quitado correctamente');

        return back();
    }

    //Eliminar una asignacion de proyecto Multiple
    public function removeProjectMultiple(){
        $id_asignaciones = json_decode($_GET['idAsignaciones']);
        foreach ($id_asignaciones as $key => $value) {
            DB::table('project_revisor')->where('id', $value)->delete();
        }

        echo json_encode(array("status"=>"ok"));
        exit;
    }
}
