<?php

namespace App\Http\Controllers;

use App\Project;
use App\Team;
use App\Type;
use App\User;
use App\Userdata;
use Cviebrock\EloquentTaggable\Models\Tag;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use App\Inscription;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Response;
use App\Http\Requests\InscriptionStore;
use Illuminate\Support\Facades\Hash;
use App\Http\Controllers\MailController;
use App;
use Mcamara\LaravelLocalization\LaravelLocalization;

class InscriptionController extends Controller
{
//    public function __construct()
//    {
//        $this->middleware('auth');
//    }


//test




    public function documents()
    {

        $args = [
            'type' => 'documents',
        ];

        return view('forms.inscription.documents', $args);
    }
    public function help()
    {

        $args = [
            'type' => 'help',
        ];

        return view('forms.inscription.help', $args);
    }

    public function index()
    {

        $args = array(
            'user' => Auth::user(),
            'inscriptions' => Inscription::where('user_id', Auth::user()->id)->get()
        );
        return view('forms.inscription.collection', $args);

    }

    public function create($type)
    {
        $args = [
            'type' => $type,
        ];

        return view('forms.inscription.create', $args);
    }


    public function slugify($text)
    {
        // replace non letter or digits by -
        $text = preg_replace('~[^\pL\d]+~u', '-', $text);
        // transliterate
        $text = iconv('utf-8', 'us-ascii//TRANSLIT', $text);
        // remove unwanted characters
        $text = preg_replace('~[^-\w]+~', '', $text);
        // trim
        $text = trim($text, '-');
        // remove duplicate -
        $text = preg_replace('~-+~', '-', $text);
        // lowercase
        $text = strtolower($text);
        if (empty($text)) {
            return 'n-a';
        }
        return $text;
    }


    public function store(InscriptionStore $request)
    {
        $project = Project::where('hash', $request->uid)->first();

        if ($project->user_id) {

            $results = [
                'status' => 'repeated',
                'data' => $request->all(),
            ];


            $statusCode = 200;
            return Response::json($results, $statusCode);

        } else {


            //create user
            $user = User::where('email', $request->email)->first();

            //get tag model by slug
            $type = Type::where('slug', $request->type)->first();

            if (!$user) {
                $user = new User();
                $user->name = $this->slugify($request->names . $request->surname);
                $user->password = Hash::make(str_random(16));
                $user->email = $request->email;
                $user->save();


                // create userdata

                $userdata = new Userdata();
                $userdata->name = $request->names;
                $userdata->surname = $request->surname;
                $userdata->dni = $request->dni;
                $userdata->dni_type = $request->dni_type;
                $userdata->address = $request->address;
                $userdata->city = $request->city;
                $userdata->country_id = $request->country_id;
                $userdata->nacionality = $request->nacionality;
                $userdata->birthdate = $request->birthdate;
                $userdata->telephone = $request->telephone;
                $userdata->cellphone = $request->cellphone;
                $userdata->user_id = $user->id;


                $userdata->save();

                $user->assignRole('postulante');
            }
            else{
                $rolesActuales = $user->getRoleNames()->toArray();

                if (! in_array('postulante', $rolesActuales)) {
                    array_push($rolesActuales, 'postulante');
                    $user->syncRoles($rolesActuales);
                }
            }

            $last_id = Project::where('projects.title', '!=', 'null')
                                ->max('origin_id');


            // get project by hash


            $project->title = $request->project_title;
            $project->summary = $request->summary;
            $project->description = $request->description;
            $project->space = $request->space;
            $project->estimated_bucket = $request->estimated_budget;
            $project->type = $request->type;
            $project->complementary_info = $request->complementary_info;
            $project->material_link = $request->video_link;
            $project->material_password = $request->video_link_password;
            $project->origin_id         = $last_id +1;
            $project->user_id = $user->id;

            if (strtolower($project->title) == "testeo") {
                $project->active = 0;
            }

            if ($request->group_name) {
                $project->team = $request->team;
            }


            $project->save();


            //if type artist save tags
            if ($request->type == 'artist') {
                if (count($request->tags) > 0) {
                    foreach ($request->tags as $tag) {
                        if ($tag == 'others') {
                            $tag = 'other';
                        }
                        $project->tag($tag);
                    }
                }
            }


            //if team create team
            if ($request->group == 'yes') {
                $team = new Team();
                if ($request->group_name) {
                    $team->name = $request->group_name;
                    $team->user_id = $user->id;
                }
                $team->save();

                $team->members()->save($user);

                $project->team_id = $team->id;
                $project->save();

                if ($request->members) {


                    if (count($request->members) > 0) {
                        foreach ($request->members as $member) {

                            $member = (object)$member;
                            $usermember = User::where('email', $member->email)->first();

                            if (!$usermember) {


                                $usermember = new User();
                                $usermember->name = $this->slugify($member->names . $member->surname);
                                $usermember->password = Hash::make(str_random(16));
                                $usermember->email = $member->email;
                                $usermember->save();


                                $member_userdata = new Userdata();
                                $member_userdata->name = $member->names;
                                $member_userdata->surname = $member->surname;
                                $member_userdata->dni = $member->dni;
                                $member_userdata->dni_type = $member->dni_type;
                                $member_userdata->address = $member->address;
                                $member_userdata->city = $member->city;
                                $member_userdata->country_id = $member->country_id;
                                $member_userdata->nacionality = $member->nacionality;
                                $member_userdata->birthdate = $member->birthdate;
                                $member_userdata->telephone = $member->telephone;
                                $member_userdata->cellphone = $member->cellphone;
                                $member_userdata->user_id = $usermember->id;
                                $member_userdata->save();

                                $usermember->assignRole('postulante');
                            }
                            else{
                                $rolesActualesMenber = $usermember->getRoleNames()->toArray();

                                if (! in_array('postulante', $rolesActualesMenber)) {
                                    array_push($rolesActualesMenber, 'postulante');
                                    $usermember->syncRoles($rolesActualesMenber);
                                }
                            }

                            $team->members()->save($usermember);
                        }
                    }
                }

            }


            //create inscription


            $inscription = new Inscription();
            $inscription->hash = $request->uid;
            $inscription->user_id = $user->id;
            $inscription->project_id = $project->id;
            $inscription->type_id = $type->id;
            $inscription->save();


            //Envio de email al inscripto
            $emailInscripto = new MailController();

            // $urlActual = url()->current();
            // $partirUrl = explode('/inscription', $urlActual);
            // $arrayUrl = explode('/', $partirUrl[0]);
            // $lang = end($arrayUrl);

            // $lang = App::getLocale();

            $lang = $request->lang;

             // $emailInscripto->sendMailInscription("gsdfg45sdfgsdf84gsdf4", $request->email, $lang);
            $emailInscripto->sendMailInscription(md5(microtime()), $request->email, $lang);

            //oki
            $results = [
                'status' => '200',
                'type' => $type->slug,
                'data' => $request->all(),
            ];


//            if no attachments return 401
//
//                   $results = [
//                       'status' => '401',
//                       'type' => $type->slug,
//                       'data' => $request->all(),
//                   ];
//                }




            $statusCode = 200;
            return Response::json($results, $statusCode);
        }
    }
}
