<?php

namespace App;

use Illuminate\Database\Eloquent\Model;
use Cviebrock\EloquentTaggable\Taggable;
use Nicolaslopezj\Searchable\SearchableTrait;

class Project extends Model
{
    use Taggable;
    use SearchableTrait;


    protected $fillable = [ 'title', 'summary','description','space','estimated_bucket','complementary_info', 'material_link', 'material_password', 'user_id' ];


    // Buscador, prioridad
    /**
     * Searchable rules.
     *
     * @var array
     */
    protected $searchable = [
        /**
         * Columns and their priority in search results.
         * Columns with higher values are more important.
         * Columns with equal values have equal importance.
         *
         * @var array
         */
        'columns' => [
            'userdata.name' => 10,
            'userdata.surname' => 10,
            // 'userdata.fullname' => 10,

            'users.email' => 5,
            'projects.title' => 5,
            'projects.description' => 5,

            'projects.summary' => 2,
            'projects.complementary_info' => 2,
            'projects.origin_id' => 2,
            'userdata.dni' => 2,
        ],
        'joins' => [
            'users' => ['users.id','projects.user_id'],
            'userdata' => ['userdata.user_id','users.id'],
        ],
    ];



    // public function getAsignationType($project_id, $user_id){

    //     DB::select("select * from project_revisor as pr where  project_id = ? and user_id = ? ", [$project_id, $user_id])


    //     return 
    // }
    

    // RELACIONES:

    // public function user(){
    //     return $this->hasOne('App\User','id','user_id');
    // }

    public function user(){
        return $this->belongsTo('App\User', 'user_id', 'id');
    }

    public function userdata(){
        return $this->belongsTo('App\Userdata', 'user_id', 'user_id');
    }

    public function teams(){
        return $this->belongsTo('App\Team', 'team_id', 'id')->withDefault(['name' => 'sin equipo']);
    }

    public function attachments(){
        return $this->hasMany('App\Attachment', 'project_id', 'id');
    }

    public function reviews(){
        return $this->hasMany('App\Review', 'project_id', 'id');
    }

    public function inscription(){
        return $this->hasOne('App\Inscription', 'project_id', 'id');
    }

    public function assignment(){
        return $this->hasMany('App\Assignment', 'project_id', 'id');
    }

    // (Categorias con Relación intermedia) 6to parametro no existe en la tabla taggable_taggables
    // public function categories(){
    //     return $this->hasManyThrough('App\TaggableTag', 'App\TaggableTaggable', 'taggable_id', 'tag_id', 'id', 'id');
    // }

    // (Categorias con Relación polimórfica muchos a muchos)
    // public function categories(){
    //     return $this->morphToMany('App\TaggableTag', 'taggable_taggables');
    // }
}
