import React from 'react';

import {renderTextField} from "./TextField";
import {Field} from 'redux-form';
import {renderSelectField} from "./SelectField";
import MenuItem from 'material-ui/MenuItem'
import {DatePicker} from 'redux-form-material-ui';

const DateTimeFormat = global.Intl.DateTimeFormat;

export const renderMembers = ({fields, meta: {error, submitFailed}, localization, countries}) => (
    <ul>

        {fields.map((member, index) => (
            <li key={index}>
                <div className="member-row">
                    <div className="member-index">
                        {localization.member} #{index + 1}
                    </div>
                    <div className="field-group">

                        <Field
                            className="form-field array-field member-names"

                            name={`${member}.names`}
                            type="text"
                            component={renderTextField}
                            autoComplete={`${member}.names`}
                            label={localization.names}/>
                        <Field
                            className="form-field array-field  member-surname"

                            name={`${member}.surname`}
                            type="text"
                            component={renderTextField}
                            autoComplete={`${member}.surname`}

                            label={localization.surname}/>
                        <Field
                            className="form-field array-field  member-email"

                            name={`${member}.email`}
                            type="text"
                            component={renderTextField}
                            autoComplete={`${member}.email`}

                            label={localization.email}/>
                    </div>
                    <div className="field-group">
                        <Field className="form-field" name={`${member}.dni_type`} id="dnitype"
                               style={{maxWidth: '180px'}}
                               component={renderSelectField}

                               label={localization.dni_type}>
                            <MenuItem value="DNI" primaryText="DNI"/>
                            <MenuItem value="CI" primaryText="CI"/>
                            <MenuItem value="LE" primaryText="LE"/>
                            <MenuItem value="LC" primaryText="LC"/>
                            <MenuItem value="otro" primaryText={localization.other}/>
                        </Field>


                        <Field
                            className="form-field"
                            style={{maxWidth: '250px'}}
                            id="dni"
                            name="dni"
                            name={`${member}.dni`}
                            type="text"
                            component={renderTextField}
                            label={localization.dni}
                            autoComplete="dni"

                        />

                    </div>

                    <div className="field-group">
                        <Field
                            className="form-field"
                            id="address"
                            name={`${member}.address`}
                            type="text"
                            component={renderTextField}
                            label={localization.address}
                            autoComplete="address"

                        />
                    </div>
                    <div className="field-group">
                        <Field
                            className="form-field"
                            id="city"
                            name={`${member}.city`}
                            type="text"
                            component={renderTextField}
                            label={localization.city}
                            autoComplete="city"
                        />


                        <Field className="form-field"
                               name={`${member}.country_id`}
                               component={renderSelectField}
                               label={localization.country}>

                            {countries.map(item => <MenuItem key={item.id} value={item.id}
                                                             primaryText={item[localization.lang]}/>)}

                        </Field>
                    </div>
                    <div className="field-group">

                        <Field
                            className="form-field"
                            id="nacionality"
                            name={`${member}.nacionality`}
                            type="text"
                            component={renderTextField}
                            label={localization.nacionality}
                            autoComplete="nacionality"
                        />

                        <Field
                            className="form-field"
                            id="birthdate"
                            name={`${member}.birthdate`}
                            floatingLabelText="Birth date"
                            component={DatePicker}
                            hintText="es-AU locale"
                            DateTimeFormat={DateTimeFormat}
                            locale="en-AU"
                            formatDate={new DateTimeFormat('en-AU', {
                                day: 'numeric',
                                month: 'numeric',
                                year: 'numeric',
                            }).format}
                            firstDayOfWeek={0}
                        />
                    </div>
                    <div className="field-group">
                        <Field
                            className="form-field"
                            id="telephone"
                            name={`${member}.telephone`}
                            type="text"
                            component={renderTextField}
                            label={localization.telephone}
                            autoComplete="telephone"

                        />
                        <Field
                            className="form-field"
                            id="cellphone"
                            name={`${member}.cellphone`}
                            type="text"
                            component={renderTextField}
                            label={localization.cellphone}
                            autoComplete="cellphone"
                        />

                    </div>

                    <button className="delete-member-button"
                            type="button"
                            title={localization.delete_member}
                            onClick={() => fields.remove(index)}>X
                    </button>
                </div>

                <br/><br/>
                <hr/>

            </li>
        ))}

        <li>
            <br/>
            <button type="button" onClick={() => fields.push({})}>
                {localization.add_member}
            </button>
            {submitFailed && error && <span>{error}</span>}
        </li>
    </ul>
)