@extends('admin.layouts.app')
@section('content')
    <h1 class="page-header">Editar Grupo</h1>

    <div class="panel panel-default">
        <div class="panel-heading">
            <h3 class="panel-title">Datos</h3>
        </div>

        {{-- Mensajes --}}
        <div class="row">
            <div class="col-xs-12 col-sm-7 col-sm-offset-3">
                {{-- De error --}}
                @if ($errors->any())
                    @foreach ($errors->all() as $error)
                        @if(!$errors->has('revisores'))
                            <div class="alert alert-danger">
                                <ul>
                                    <li>{{ $error }}</li>
                                </ul>
                            </div>
                        @endif
                    @endforeach
                @endif
                
                {{-- De exito --}}
                @if(Session::has('guardado'))
                    <div class="alert alert-success" role="alert">
                        {{Session::get('guardado', '')}}
                    </div>
                @endif
            </div>  
        </div>


        <div class="panel-body">

            {!! Form::open(array('route' => ['group.update', $group->id],  'method' => 'PATCH','enctype'=>"multipart/form-data", 'class' => 'form-horizontal')) !!}

            {!!   Form::token() !!}


            <div class="form-group">
                {!! Form::label('', 'Nombre:', ['class' => 'col-sm-3']) !!}
                <div class="col-sm-9">
                    {!! Form::text('name', $group->name, ['class' => 'form-control']) !!}
                </div>
            </div>

            <div class="form-group">
                {!! Form::label('', 'Slug:', ['class' => 'col-sm-3']) !!}
                <div class="col-sm-9">
                    {!! Form::text('slug', $group->slug, ['class' => 'form-control']) !!}
                </div>
            </div>

            <div class="form-group text-center">
                {!! Form::submit() !!}<br>
            </div>


            {!! Form::close() !!}
        </div>
    </div>


    {{-- Asignar usuarios al grupo --}}
        <div class="panel panel-default">
            <div class="panel-heading">
                <h3 class="panel-title">Integrantes ({{ $group->name }})</h3>
            </div>

            {{-- De exito --}}
            @if(Session::has('revisorQuitado'))
                <div class="alert alert-success" role="alert">
                    {{Session::get('revisorQuitado', '')}}
                </div>
            @endif

            <div class="panel-body">
                @foreach($revisoresDelGrupo as $key => $value)
                    <div class="form-group row">
                        {!! Form::label('', 'Revisor: ', ['class' => 'col-sm-3']) !!}
                        <div class="col-sm-5">
                            {{ $value->nombreRevisor }}
                        </div>

                        <div class="col-sm-4">
                            {!! Form::open(array('route' => ['removeRevisorGroup', $value->id],  'method' => 'POST','enctype'=>"multipart/form-data", 'class' => 'form-horizontal')) !!}

                                {!! Form::token() !!}

                                <input name="_method" type="hidden" value="DELETE">
                                
                                {!! Form::submit('Quitar', ['class' => 'btn btn-danger btn-xs']) !!}
                            {!! Form::close() !!}
                        </div>
                    </div>
                @endforeach
            </div>
        </div>
        
        <div class="panel panel-default">
            <div class="panel-heading">
                <h3 class="panel-title">Agregar integrante ({{ $group->name }})</h3>
            </div>
        

            @if($errors->has('revisores'))
                <div class="alert alert-danger">
                    <ul>
                        @foreach ($errors->all() as $error)
                            <li>{{ $error }}</li>
                        @endforeach
                    </ul>
                </div>
            @endif

            {{-- De exito --}}
            @if(Session::has('revisorAgregado'))
                <div class="alert alert-success" role="alert">
                    {{Session::get('revisorAgregado', '')}}
                </div>
            @endif

            <div class="panel-body">
                {!! Form::open(array('route' => ['addRevisorGroup'],  'method' => 'POST','enctype'=>"multipart/form-data", 'class' => 'form-horizontal')) !!}

                    {!! Form::token() !!}

                    {!! Form::hidden('idGroup', $group->id) !!}
                    

                    <div class="form-group">
                        {!! Form::label('', 'Revisor:', ['class' => 'col-sm-3']) !!}
                        <div class="col-sm-9">
                            <label for="id_label_multiple">
                                Agregar revisores
                                <select name="revisores[]" id="revisores" class="js-example-basic-multiple" multiple="multiple" style="width: 100%">
                                </select>
                            </label>
                        </div>
                    </div>

                    <div class="form-group text-center">
                        {!! Form::submit() !!}<br>
                    </div>


                {!! Form::close() !!}
            </div>
        </div>


        {{-- asignar proyectos al grupo --}}
        <div class="panel panel-default">
            <div class="panel-heading">
                <h3 class="panel-title">Proyectos asignados ({{ $group->name }})</h3>
            </div>

            {{-- De exito --}}
            @if(Session::has('asignacionBorrada'))
                <div class="alert alert-success" role="alert">
                    {{Session::get('asignacionBorrada', '')}}
                </div>
            @endif

            <div class="panel-body">
                @foreach($proyectosAsignados as $key => $value)
                {{-- {{dd($value)}} --}}
                    <div class="form-group row">
                        {!! Form::label('', 'Etapa ' . $value->nombreEtapa, ['class' => 'col-sm-3']) !!}
                        <div class="col-sm-5">
                            {{ $value->tituloProyecto }}
                        </div>

                        <div class="col-sm-4">
                            {!! Form::open(array('route' => ['removeProjectGroup'],  'method' => 'POST','enctype'=>"multipart/form-data", 'class' => 'form-horizontal')) !!}

                                {!! Form::token() !!}

                                {!! Form::hidden('idGroup', $value->group_id) !!}
                                {!! Form::hidden('idProject', $value->project_id) !!}
                                {!! Form::hidden('idStage', $value->stage_id) !!}

                                <input name="_method" type="hidden" value="DELETE">
                                
                                {!! Form::submit('Quitar', ['class' => 'btn btn-danger btn-xs']) !!}
                            {!! Form::close() !!}
                        </div>
                    </div>
                @endforeach
            </div>
        </div>
        
        <div class="panel panel-default">
            <div class="panel-heading">
                <h3 class="panel-title">Asignar proyectos ({{ $group->name }})</h3>
            </div>

            @if ($errors->has('stages') || $errors->has('projects'))
                <div class="alert alert-danger">
                    <ul>
                        @foreach ($errors->all() as $error)
                            <li>{{ $error }}</li>
                        @endforeach
                    </ul>
                </div>
            @endif

            {{-- De exito --}}
            @if(Session::has('asignado'))
                <div class="alert alert-success" role="alert">
                    {{Session::get('asignado', '')}}
                </div>
            @endif

            <div class="panel-body">
            {!! Form::open(array('route' => ['saveProjectsGroup'],  'method' => 'POST','enctype'=>"multipart/form-data", 'class' => 'form-horizontal')) !!}

                {!! Form::token() !!}

                {!! Form::hidden('idGroup', $group->id) !!}
                

                <div class="form-group">
                    {!! Form::label('', 'Etapa:', ['class' => 'col-sm-3']) !!}
                    <div class="col-xs-12 col-sm-5">
                        <select name="stages" id="stages" class="form-control js-example-basic-multiple">
                        </select>
                    </div>
                </div>

                <div class="form-group">
                    {!! Form::label('', 'Proyecto:', ['class' => 'col-sm-3']) !!}
                    <div class="col-sm-9">
                        <label for="id_label_multiple">
                            Proyectos
                            <select name="projects[]" id="projects" class="js-example-basic-multiple" multiple="multiple" style="width: 100%" disabled="disabled">
                            </select>
                        </label>
                    </div>
                </div>

                <div class="form-group text-center">
                    {!! Form::submit() !!}<br>
                </div>


                {!! Form::close() !!}
            </div>
        </div>


@endsection

@section('scripts')


    <script type="text/javascript">
        $( document ).ready(function() {
            // Inicializacion
            $('.js-example-basic-multiple').select2();


            // asignacion de revisores al grupo
            //Select (revisores)
            $("#revisores").html();

            var request = $.ajax({
                url: '{{ url("/admin/getRevisorGroup/") }}',
                method: "GET",
                dataType: "json"
            });
             
            request.done(function( obj ) {
                // Add returned options
                $.each(obj, function (index) {   
                    console.log(obj[index].name);
                    valor = obj[index].id;
                    texto = obj[index].name;

                    $("#revisores").append('<option value=' + valor + '>' + texto + '</option>');
                });
             });




            // asignacion de proyectos al grupo

            //Select (stages)
            $("#stages").html();
            $("#stages").html("<option value=''>Etapa</option>");

            var request = $.ajax({
                url: '{{ url("/admin/getStagesGroup/") }}',
                method: "GET",
                dataType: "json"
            });
             
            request.done(function( obj ) {
                // Add returned options
                $.each(obj, function (index) {   
                    // console.log(obj[index].name);
                    valor = obj[index].id;
                    texto = obj[index].name;

                    $("#stages").append('<option value=' + valor + '>' + texto + '</option>');
                });
             });


            //Select (projects)
            $('#stages').change(function(){
                $('#projects').select2('destroy');
                $('#projects').select2();

                $('#projects').removeAttr("disabled");

                $("#projects").html('');
                
                var request = $.ajax({
                    url: '{{ url("/admin/getProjectsGroup/") }}',
                    method: "GET",
                    data: { idGroup : {{ $group->id }}, idStage : $("#stages").val()}, 
                    dataType: "json"
                });
                 
                request.done(function( obj ) {
                    // Add returned options
                    console.log(obj);
                    $.each(obj, function (index) {   
                        // console.log(obj[index].name);
                        valor = obj[index].id;
                        texto = obj[index].title;

                        $("#projects").append('<option value=' + valor + '>' + texto + '</option>');
                        
                        //borra options repetidos
                        var code = {};
                        $("#projects > option").each(function () {
                            if(code[this.text]) {
                                $(this).remove();
                            } else {
                                code[this.text] = this.value;
                            }
                        });                        

                    });
                 });
            });

//cierre de ready
});

    </script>
@endsection